@@ -12,7 +12,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized numeric once );
 
-our $VERSION = '1.809';
+our $VERSION = '1.810';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (Subroutines::ProhibitExplicitReturnUndef)
@@ -47,12 +47,20 @@ BEGIN {
    eval 'use PDL::IO::Storable' if $INC{'PDL.pm'};
 
    if (!exists $INC{'PDL.pm'}) {
-      eval 'use Sereal 3.008 qw( encode_sereal decode_sereal )';
+      eval '
+         use Sereal::Encoder 3.015 qw( encode_sereal );
+         use Sereal::Decoder 3.015 qw( decode_sereal );
+      ';
       if ( !$@ ) {
-         $_freeze = sub { encode_sereal( @_, { freeze_callbacks => 1 } ) };
-         $_thaw   = \&decode_sereal;
+         my $_encoder_ver = int( Sereal::Encoder->VERSION() );
+         my $_decoder_ver = int( Sereal::Decoder->VERSION() );
+         if ( $_encoder_ver - $_decoder_ver == 0 ) {
+            $_freeze = sub { encode_sereal( @_, { freeze_callbacks => 1 } ) };
+            $_thaw   = \&decode_sereal;
+         }
       }
    }
+
    if (!defined $_freeze) {
       require Storable;
       $_freeze = \&Storable::freeze;
@@ -2284,7 +2292,7 @@ MCE::Shared::Server - Server/Object packages for MCE::Shared
 
 =head1 VERSION
 
-This document describes MCE::Shared::Server version 1.809
+This document describes MCE::Shared::Server version 1.810
 
 =head1 DESCRIPTION
 
